// Copyright (c) 2014-2022 NetEase, Inc.
// All right reserved.

import 'dart:async';
import 'dart:math';

import 'package:netease_common/netease_common.dart';
import 'package:netease_roomkit_interface/src/pigeon.dart';
import 'package:netease_roomkit_interface/src/platform_interface/message_service_platform.dart';
import 'package:netease_roomkit_interface/src/platform_interface/room_context_platform.dart';

class MethodChannelMessageEventSink extends MessageEventSink {
  final _listeners = <MessageEventSink>[];

  void addMessageListener(MessageEventSink sink) {
    _listeners.add(sink);
  }

  void removeMessageListener(MessageEventSink sink) {
    _listeners.remove(sink);
  }

  @override
  void onReceivePassThroughMessage(PassThroughMessageEvent messageEvent) {
    for (var element in _listeners) {
      element.onReceivePassThroughMessage(messageEvent);
    }
  }
}

class MethodChannelMessageService extends MessageServicePlatform {
  final _eventDispatcher = MethodChannelMessageEventSink();
  final _api = MessageServiceApi();

  MethodChannelMessageService() {
    MessageEventSink.setup(_eventDispatcher);
  }

  @override
  void addMessageListener(MessageEventSink sink) {
    _eventDispatcher.addMessageListener(sink);
  }

  @override
  void removeMessageListener(MessageEventSink sink) {
    _eventDispatcher.removeMessageListener(sink);
  }

  @override
  Future<VoidResult> sendPassThroughMessage(String roomUuid, String userUuid, String data) {
    return _api
        .sendPassThroughMessage(roomUuid, userUuid, data)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

}
