import 'package:netease_common/src/api_result.dart';
import 'package:netease_roomkit_interface/src/pigeon.dart';
import 'package:netease_roomkit_interface/src/platform_interface/room_rtc_controller_platform.dart';
import 'package:netease_roomkit_interface/src/types/rtc_models.dart';

class MethodChannelRoomRtcController extends RoomRtcControllerPlatform {
  final _api = RoomRtcControllerApi();

  @override
  Future<VoidResult> joinRtcChannel(String roomUuid) {
    return _api
        .joinRtcChannel(roomUuid)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> leaveRtcChannel(String roomUuid) {
    return _api
        .leaveRtcChannel(roomUuid)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> muteMyAudio(String roomUuid) {
    return _api
        .muteMyAudio(roomUuid)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> muteMyVideo(String roomUuid) {
    return _api
        .muteMyVideo(roomUuid)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> stopScreenShare(String roomUuid) {
    return _api
        .stopScreenShare(roomUuid)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> subscribeRemoteSubStreamVideo(
      String roomUuid, String userUuid, bool subscribe) {
    return _api
        .subscribeRemoteSubStreamVideo(roomUuid, userUuid, subscribe)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> subscribeRemoteVideoStream(
      String roomUuid, String userUuid, bool subscribe) {
    return _api
        .subscribeRemoteVideoStream(roomUuid, userUuid, subscribe)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }


  @override
  Future<VoidResult> adjustUserPlaybackSignalVolume(String roomUuid, String userUuid, int volume) {
    return _api
        .adjustUserPlaybackSignalVolume(roomUuid, userUuid, volume)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> unmuteMyAudio(String roomUuid) {
    return _api
        .unmuteMyAudio(roomUuid)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> unmuteMyVideo(String roomUuid) {
    return _api
        .unmuteMyVideo(roomUuid)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> stopMemberScreenShare(String roomUuid, String uuid) {
    return _api
        .stopMemberScreenShare(roomUuid, uuid)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> muteMemberAudio(String roomUuid, String uuid) {
    return _api
        .muteMemberAudio(roomUuid, uuid)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> muteMemberVideo(String roomUuid, String uuid) {
    return _api
        .muteMemberVideo(roomUuid, uuid)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> unmuteMemberAudio(String roomUuid, String uuid) {
    return _api
        .unmuteMemberAudio(roomUuid, uuid)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> unmuteMemberVideo(String roomUuid, String uuid) {
    return _api
        .unmuteMemberVideo(roomUuid, uuid)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> startScreenShare(String roomUuid, {String? iosAppGroup}) {
    return _api
        .startScreenShare(StartScreenShareRequest(
            roomUuid: roomUuid, iosAppGroup: iosAppGroup))
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> enableAudioVolumeIndication(
      String roomUuid, bool enable, int interval) {
    return _api
        .enableAudioVolumeIndication(roomUuid, enable, interval)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<bool> isSpeakerphoneOn(String roomUuid) {
    return _api.isSpeakerphoneOn(roomUuid).then((value) => value.code == 0);
  }

  @override
  Future<VoidResult> setSpeakerphoneOn(String roomUuid, bool on) {
    return _api
        .setSpeakerphoneOn(roomUuid, on)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> startAudioDump(String roomUuid, NEAudioDumpType type) {
    return _api
        .startAudioDump(roomUuid, type.index)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> stopAudioDump(String roomUuid) {
    return _api
        .stopAudioDump(roomUuid)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> startRtcChannelMediaRelay(String roomUuid) {
    return _api
        .startRtcChannelMediaRelay(roomUuid)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> stopRtcChannelMediaRelay(String roomUuid) {
    return _api
        .stopRtcChannelMediaRelay(roomUuid)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> startAudioMixing(
      String roomUuid, NECreateAudioMixingOption option) {
    return _api
        .startAudioMixing(
            roomUuid,
            CreateAudioMixingOption(
              path: option.path,
              loopCount: option.loopCount,
              playbackVolume: option.playbackVolume,
              playbackEnabled: option.playbackEnabled,
              sendEnabled: option.sendEnabled,
              sendVolume: option.sendVolume,
            ))
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> playEffect(
      String roomUuid, int id, NECreateAudioEffectOption option) {
    return _api
        .playEffect(
            roomUuid,
            id,
            CreateAudioEffectOption(
              path: option.path,
              loopCount: option.loopCount,
              playbackVolume: option.playbackVolume,
              playbackEnabled: option.playbackEnabled,
              sendEnabled: option.sendEnabled,
              sendVolume: option.sendVolume,
            ))
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> stopAudioMixing(String roomUuid) {
    return _api
        .stopAudioMixing(roomUuid)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> stopEffect(String roomUuid, int id) {
    return _api
        .stopEffect(roomUuid, id)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> setAudioMixingSendVolume(String roomUuid, int volume) {
    return _api
        .setAudioMixingSendVolume(roomUuid, volume)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> setAudioMixingPlaybackVolume(String roomUuid, int volume) {
    return _api
        .setAudioMixingPlaybackVolume(roomUuid, volume)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> setEffectSendVolume(String roomUuid, int id, int volume) {
    return _api
        .setEffectSendVolume(roomUuid, id, volume)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> setEffectPlaybackVolume(
      String roomUuid, int id, int volume) {
    return _api
        .setEffectPlaybackVolume(roomUuid, id, volume)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> stopAllEffects(String roomUuid) {
    return _api
        .stopAllEffects(roomUuid)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> enableEarBack(String roomUuid, bool enable, int volume) {
    return _api
        .enableEarBack(roomUuid, enable, volume)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> switchCamera() {
    return _api
        .switchCamera()
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> addBeautyFilter(String path) {
  return _api
      .addBeautyFilter(path)
      .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> addBeautySticker(String path) {
  return _api
      .addBeautySticker(path)
      .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> enableBeauty(bool isOpenBeauty) {
    return _api
        .enableBeauty(isOpenBeauty)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> removeBeautyFilter() {
    return _api
        .removeBeautyFilter()
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> removeBeautySticker() {
    return _api
        .removeBeautySticker()
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> setBeautyEffect(
      NERoomBeautyEffectType beautyType, double level) {
    return _api
        .setBeautyEffect(
        NERoomBeautyEffectTypeExtension.fromType(beautyType), level)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> setBeautyFilterLevel(double level) {
    return _api
        .setBeautyFilterLevel(level)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> startBeauty() {
    return _api
        .startBeauty()
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> stopBeauty() {
    return _api
        .stopBeauty()
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }
}
