// Copyright (c) 2014-2022 NetEase, Inc.
// All right reserved.

import 'package:netease_common/netease_common.dart';
import 'package:netease_roomkit_interface/src/pigeon.dart';
import 'package:netease_roomkit_interface/src/platform_interface/room_service_platform.dart';
import 'package:netease_roomkit_interface/src/types/room_service_models.dart';

class MethodChannelRoomService extends RoomServicePlatform {

  final _api = RoomServiceApi();


  @override
  Future<VoidResult> createRoom(params, options) {
    return _api.createRoom(
      CreateRoomParams(
        roomUuid: params.roomUuid,
        roomName: params.roomName,
        password: params.password,
        templateId: params.templateId,
        initialProperties: params.initialRoomProperties,
      ),
      CreateRoomOptions(
        enableRecord: options.enableRecord,
        enableLive: options.enableLive,
        enableRtc: options.enableRtc,
        enableChatroom: options.enableChatroom,
        enableWhiteboard: options.enableWhiteboard,),
    ).then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<NEResult<RoomSnapshot>> joinRoom(NEJoinRoomParams params, NEJoinRoomOptions options) {
    return _api.joinRoom(
      JoinRoomParams(
        roomUuid: params.roomUuid,
        userName: params.userName,
        password: params.password,
        role: params.role,
        initialProperties: params.initialMyProperties,
      ),
      JoinRoomOptions(unUsed: 0),
    ).then((value) {
      return NEResult(code: value.code, msg: value.msg, data: value.snapshot);
    });
  }

  @override
  Future<VoidResult> previewRoom(
      NEPreviewRoomParams params, NEPreviewRoomOptions options){
    return _api.previewRoom(PreviewRoomParams(), PreviewRoomOptions())
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

}
