import 'package:plugin_platform_interface/plugin_platform_interface.dart';
import 'package:netease_common/netease_common.dart';
import 'package:netease_roomkit_interface/netease_roomkit_interface.dart';
import 'package:netease_roomkit_interface/src/method_channel/method_channel_room_rtc_controller.dart';

abstract class RoomRtcControllerPlatform extends PlatformInterface{
  static final Object _token = Object();

  RoomRtcControllerPlatform() : super(token: _token);

  static RoomRtcControllerPlatform _instance = MethodChannelRoomRtcController();

  static RoomRtcControllerPlatform get instance => _instance;

  static set instance(RoomRtcControllerPlatform instance) {
    PlatformInterface.verify(instance, _token);
    _instance = instance;
  }


  Future<VoidResult> joinRtcChannel(String roomUuid);

  Future<VoidResult> leaveRtcChannel(String roomUuid);

  Future<VoidResult> muteMyAudio(String roomUuid);

  Future<VoidResult> unmuteMyAudio(String roomUuid);

  Future<VoidResult> muteMyVideo(String roomUuid);

  Future<VoidResult> unmuteMyVideo(String roomUuid);

  Future<VoidResult> muteMemberAudio(String roomUuid,String uuid);

  Future<VoidResult> unmuteMemberAudio(String roomUuid,String uuid);

  Future<VoidResult> muteMemberVideo(String roomUuid,String uuid);

  Future<VoidResult> unmuteMemberVideo(String roomUuid,String uuid);

  Future<VoidResult> startScreenShare(String roomUuid, {String? iosAppGroup});

  Future<VoidResult> stopScreenShare(String roomUuid);

  Future<VoidResult> stopMemberScreenShare(String roomUuid,String uuid);

  Future<VoidResult> subscribeRemoteVideoStream(String roomUuid,String userUuid,bool subscribe);

  Future<VoidResult> adjustUserPlaybackSignalVolume(String roomUuid,String userUuid,int volume);

  Future<VoidResult> subscribeRemoteSubStreamVideo(String roomUuid,String userUuid,bool subscribe);

  Future<VoidResult> setSpeakerphoneOn(String roomUuid, bool on);

  Future<bool> isSpeakerphoneOn(String roomUuid);

  Future<VoidResult> stopAudioDump(String roomUuid);

  Future<VoidResult> startAudioDump(String roomUuid, NEAudioDumpType type);

  Future<VoidResult> enableAudioVolumeIndication(String roomUuid, bool enable, int interval);

  Future<VoidResult> startRtcChannelMediaRelay(String roomUuid);

  Future<VoidResult> stopRtcChannelMediaRelay(String roomUuid);

  Future<VoidResult> startAudioMixing(String roomUuid, NECreateAudioMixingOption option);

  Future<VoidResult> playEffect(String roomUuid, int id, NECreateAudioEffectOption option);

  Future<VoidResult> stopAudioMixing(String roomUuid);

  Future<VoidResult> stopEffect(String roomUuid, int id);

  Future<VoidResult> setAudioMixingSendVolume(String roomUuid, int volume);

  Future<VoidResult> setAudioMixingPlaybackVolume(String roomUuid, int volume);

  Future<VoidResult> setEffectSendVolume(String roomUuid, int id, int volume);

  Future<VoidResult> setEffectPlaybackVolume(String roomUuid, int id, int volume);

  Future<VoidResult> stopAllEffects(String roomUuid);

  Future<VoidResult> enableEarBack(String roomUuid, bool enable, int volume);


  Future<VoidResult> switchCamera();

  Future<VoidResult> addBeautyFilter(String path);

  Future<VoidResult> addBeautySticker(String path);

  Future<VoidResult> enableBeauty(bool isOpenBeauty);

  Future<VoidResult> removeBeautyFilter();

  Future<VoidResult> removeBeautySticker();

  Future<VoidResult> startBeauty();

  Future<VoidResult> stopBeauty();

  Future<VoidResult> setBeautyFilterLevel(double level);

  Future<VoidResult> setBeautyEffect(NERoomBeautyEffectType beautyType, double level);
}