// Copyright (c) 2014-2022 NetEase, Inc.
// All right reserved.

class NECreateRoomParams {
  final String roomUuid;

  final String roomName;

  final String? password;

  final String? templateId;

  final Map<String, String>? initialRoomProperties;

  NECreateRoomParams({
    required this.roomUuid,
    required this.roomName,
    this.templateId,
    this.password,
    this.initialRoomProperties,
  });
}

class NECreateRoomOptions {
  final bool enableRecord;
  final bool enableLive;
  final bool enableRtc;
  final bool enableChatroom;
  final bool enableWhiteboard;

  NECreateRoomOptions({
    this.enableRecord = false,
    this.enableLive = false,
    this.enableRtc = true,
    this.enableChatroom = true,
    this.enableWhiteboard = false,
  });
}

///
/// 加入房间参数
///
class NEJoinRoomParams {
  ///
  /// 房间id
  ///
  final String roomUuid;

  ///
  /// 用户名
  ///
  final String userName;

  ///
  /// 角色
  ///
  final String role;

  ///
  /// 密码
  ///
  final String? password;

  ///
  /// 初始化属性
  ///
  final Map<String, String>? initialMyProperties;

  NEJoinRoomParams({
    required this.roomUuid,
    required this.userName,
    required this.role,
    this.password,
    this.initialMyProperties,
  });

  @override
  String toString() {
    return 'NEJoinRoomParams{roomUuid: $roomUuid, userName: $userName, role: $role, password: $password, initialProperties: $initialMyProperties}';
  }
}

///
/// 加入房间选项
///
class NEJoinRoomOptions {
  /// 配置入会时是否关闭本端视频，默认为true，即关闭视频，但在房间中可重新打开
  late final bool noVideo;

  /// 配置入会时是否关闭本端音频，默认为true，即关闭音频，但在房间中可重新打开
  late final bool noAudio;

  /// 配置房间内智能语音降噪开关，默认开启；
  /// 如果 [audioProfile] 不为空，则优先使用 [audioProfile.enableAINS]
  @Deprecated('use `audioProfile` instead')
  // late final bool audioAINSEnabled;

  /// 音频选项
  // late final NERoomAudioProfile? audioProfile;

  /// 额外选项
  late final Map<String, dynamic> extras;

  NEJoinRoomOptions.initial();

  NEJoinRoomOptions({
    this.noVideo = true,
    this.noAudio = true,
    // this.audioAINSEnabled = true,
    // this.audioProfile,
    this.extras = const <String, dynamic>{},
  });

  @override
  String toString() {
    return 'NERoomOptions{noVideo: $noVideo, noAudio: $noAudio, extras: $extras}';
  }
}

///
/// 预览房间参数
///
class NEPreviewRoomParams {

}

///
/// 预览房间选项
///
class NEPreviewRoomOptions {

}

///
/// 房间角色
///
class NERoomRole {
  final String name;
  final int limit;
  final bool superRole;
  //final NERoleParams params;

  NERoomRole({
    required this.name,
    required this.limit,
    required this.superRole,
    //required this.params,
  });
}

///
/// 角色音视频参数
///
class NERoleParams {
  final NERoleVideoParams video;

  final NERoleAudioParams audio;

  final NERoleScreenParams screen;

  NERoleParams({
    required this.video, required this.audio, required this.screen,
  });
}

///
/// 角色所对应的视频参数
/// [width] 视频宽
/// [height] 视频高
/// [fps] 帧率
///
class NERoleVideoParams {

  final int width;

  final int height;

  final int fps;

  NERoleVideoParams({
    required this.width,
    required this.height,
    required this.fps,
  });
}

///
/// 角色所对应的屏幕共享参数
///
class NERoleScreenParams {
  final String videoProfile;

  NERoleScreenParams(this.videoProfile);
}

///
/// 角色所对应的音频参数
///
class NERoleAudioParams {
  final String profile;
  final String scenario;

  NERoleAudioParams(this.profile, this.scenario);
}

///
/// 房间成员
///
abstract class NERoomMember {
  ///
  /// 用户id
  ///
  String get uuid;

  ///
  /// 用户名
  ///
  String get name;

  ///
  /// 角色
  ///
  NERoomRole get role;

  ///
  /// 音频是否打开
  ///
  bool get isAudioOn;

  ///
  /// 视频是否打开
  ///
  bool get isVideoOn;

  ///
  /// 当前成员是否在RTC房间内
  ///
  bool get isInRtcChannel;

  ///
  /// 当前成员是否在聊天室内
  ///
  bool get isInChatroom;

  ///
  /// 当前成员是否正在屏幕共享中
  ///
  bool get isSharingScreen;

  ///
  /// 当前成员是否在共享白板
  ///
  bool get isSharingWhiteboard;

  ///
  /// 属性
  ///
  Map<String, String> get properties;
}
